searchData={"items":[{"type":"module","title":"QuickXml","doc":"QuickXml is an XML parsing library for Elixir using a Rust NIF powered by the quick-xml crate.","ref":"QuickXml.html"},{"type":"function","title":"QuickXml.parse/1","doc":"Parses an XML string into an Elixir map.","ref":"QuickXml.html#parse/1"},{"type":"function","title":"Parameters - QuickXml.parse/1","doc":"- `xml` (string): The XML content to be parsed.","ref":"QuickXml.html#parse/1-parameters"},{"type":"function","title":"Returns - QuickXml.parse/1","doc":"- `{:ok, map}` – If the XML is successfully parsed.\n  - `{:error, {error_type, message}}` – If parsing fails.","ref":"QuickXml.html#parse/1-returns"},{"type":"function","title":"Error Types - QuickXml.parse/1","doc":"- `:invalid_xml` – The XML structure is incorrect or incomplete.\n- `:unexpected_eof` – The document ends unexpectedly.\n- `:malformed_xml` – The XML contains structural issues.\n- `:unknown_error` – An unspecified error occurred during parsing.","ref":"QuickXml.html#parse/1-error-types"},{"type":"function","title":"Examples - QuickXml.parse/1","doc":"iex> QuickXml.parse(\"  John  \")\n    {:ok, %{\"name\" => %{\"$text\" => \"John\"}}}\n\n    iex> QuickXml.parse(\" \")\n    {:error, {:malformed_xml, \"ill-formed document: start tag not closed: ` ` not found before end of input\"}}\n\n    iex> QuickXml.parse(\"\")\n    {:error, {:unexpected_eof, \"no details\"}}","ref":"QuickXml.html#parse/1-examples"},{"type":"function","title":"QuickXml.parse!/1","doc":"Same as `parse/1`, but returns the parsed map directly or raises an exception if parsing fails.","ref":"QuickXml.html#parse!/1"},{"type":"type","title":"QuickXml.parse_error_type/0","doc":"","ref":"QuickXml.html#t:parse_error_type/0"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"","ref":"changelog.html#v0-1-0"},{"type":"extras","title":"Added - Changelog","doc":"- Initial release with `parse/1` function using the `quick-xml` Rust crate for XML parsing.","ref":"changelog.html#added"},{"type":"extras","title":"License","doc":"MIT License\r\n\r\nCopyright (c) 2025 Rafael Gabriel\r\n\r\nPermission is hereby granted, free of charge, to any person obtaining a copy\r\nof this software and associated documentation files (the \"Software\"), to deal\r\nin the Software without restriction, including without limitation the rights\r\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\r\ncopies of the Software, and to permit persons to whom the Software is\r\nfurnished to do so, subject to the following conditions:\r\n\r\nThe above copyright notice and this permission notice shall be included in all\r\ncopies or substantial portions of the Software.\r\n\r\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\r\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\r\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\r\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\r\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\r\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\r\nSOFTWARE.","ref":"license.html"},{"type":"extras","title":"Overview","doc":"# QuickXml\n\n[![CI](https://github.com/faelgabriel/quick_xml/actions/workflows/ci.yml/badge.svg)](https://github.com/faelgabriel/quick_xml/actions/workflows/ci.yml)\n\nQuickXml is an XML parsing library for Elixir using a Rust NIF powered by the [`quick-xml`](https://crates.io/crates/quick-xml) crate. It provides a fast and efficient way to convert XML strings into Elixir maps.","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"Add `quick_xml` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:quick_xml, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Force Compilation - Overview","doc":"This library includes pre-compiled binaries for the native Rust code. If you\nwant to force-compile the Rust code, you can add the following configuration\nto your application:\n\n```elixir\nconfig :rustler_precompiled, :force_build, quick_xml: true\n```\n\nYou also need to add Rustler to your dependencies:\n\n```elixir\ndef deps do\n  [\n    {:quick_xml, \"~> 0.1.0\"},\n    {:rustler, \">= 0.0.0\", optional: true}\n  ]\nend\n```","ref":"readme.html#force-compilation"},{"type":"extras","title":"Usage - Overview","doc":"To parse an XML string into an Elixir map, use `QuickXml.parse/1`:\n\n```elixir\nxml = \"  John  30  \"\n{:ok, parsed_map} = QuickXml.parse(xml)\n\n# Expected output:\n{:ok, %{\"age\" => %{\"$text\" => \"30\"}, \"name\" => %{\"$text\" => \"John\"}}}\n```\n\nIf the XML is invalid, it returns an error tuple:\n\n```elixir\n{:error, {:invalid_xml, \"syntax error: xml must have a node\"}}\n```","ref":"readme.html#usage"},{"type":"extras","title":"Benchmarking - Overview","doc":"It includes a benchmarking script (`benchmark.exs`) that generates mock XML content to measure parsing performance. You can run it with:\n\n```sh\nelixir benchmark.exs\n```\n\nFor custom XML content size in kilobytes, you can pass the `--kb` flag with the desired size. For example: `elixir benchmark.exs --kb 100`.","ref":"readme.html#benchmarking"},{"type":"extras","title":"Sample Benchmark Results - Overview","doc":"Click to expand \n\n```\nOperating System: Linux\nCPU Information: AMD Ryzen 5 5600GT with Radeon Graphics\nNumber of Available Cores: 12\nAvailable memory: 15.52 GB\nElixir 1.18.2\nErlang 27.2.2\nJIT enabled: true\n\nBenchmark suite executing with the following configuration:\nwarmup: 2 s\ntime: 5 s\nmemory time: 0 ns\nreduction time: 0 ns\nparallel: 4\ninputs: 1500 KB, 300 KB, 3000 KB, 50 KB\nEstimated total run time: 1 min 52 s\n```\n\n```\n##### With input 50 KB #####\nName                           ips        average  deviation         median         99th %\nQuickXml.parse/1           2162.20        0.46 ms    ±25.26%        0.40 ms        0.77 ms\nSAXMap.from_string/1        918.36        1.09 ms    ±26.53%        0.97 ms        1.90 ms\n:xmerl_scan.string/1        199.95        5.00 ms    ±27.94%        4.83 ms        8.77 ms\nSweetXml.xpath/2            131.20        7.62 ms    ±22.81%        7.43 ms       13.13 ms\n\nComparison: \nQuickXml.parse/1           2162.20\nSAXMap.from_string/1        918.36 - 2.35x slower +0.63 ms\n:xmerl_scan.string/1        199.95 - 10.81x slower +4.54 ms\nSweetXml.xpath/2            131.20 - 16.48x slower +7.16 ms\n```\n\n```\n##### With input 300 KB #####\nName                           ips        average  deviation         median         99th %\nQuickXml.parse/1            418.74        2.39 ms    ±94.70%        2.12 ms        3.49 ms\nSAXMap.from_string/1        158.07        6.33 ms    ±24.90%        5.91 ms       11.32 ms\n:xmerl_scan.string/1         21.73       46.01 ms    ±16.88%       47.00 ms       63.06 ms\nSweetXml.xpath/2             15.48       64.59 ms    ±12.66%       62.93 ms       82.58 ms\n\nComparison: \nQuickXml.parse/1            418.74\nSAXMap.from_string/1        158.07 - 2.65x slower +3.94 ms\n:xmerl_scan.string/1         21.73 - 19.27x slower +43.62 ms\nSweetXml.xpath/2             15.48 - 27.05x slower +62.20 ms\n```\n\n```\n##### With input 1500 KB #####\nName                           ips        average  deviation         median         99th %\nQuickXml.parse/1             66.33       0.0151 s   ±410.35%       0.0104 s       0.0165 s\nSAXMap.from_string/1         11.78       0.0849 s     ±5.84%       0.0841 s        0.105 s\n:xmerl_scan.string/1          0.78         1.29 s     ±2.24%         1.28 s         1.34 s\nSweetXml.xpath/2              0.67         1.49 s     ±4.33%         1.51 s         1.59 s\n\nComparison: \nQuickXml.parse/1             66.33\nSAXMap.from_string/1         11.78 - 5.63x slower +0.0698 s\n:xmerl_scan.string/1          0.78 - 85.48x slower +1.27 s\nSweetXml.xpath/2              0.67 - 98.75x slower +1.47 s\n```\n\n```\n##### With input 3000 KB #####\nName                           ips        average  deviation         median         99th %\nQuickXml.parse/1             30.64       0.0326 s   ±469.51%       0.0214 s       0.0399 s\nSAXMap.from_string/1          5.86        0.171 s     ±4.43%        0.170 s        0.196 s\n:xmerl_scan.string/1          0.34         2.97 s     ±3.32%         2.97 s         3.09 s\nSweetXml.xpath/2              0.29         3.41 s     ±1.99%         3.38 s         3.53 s\n\nComparison: \nQuickXml.parse/1             30.64\nSAXMap.from_string/1          5.86 - 5.23x slower +0.138 s\n:xmerl_scan.string/1          0.34 - 90.96x slower +2.94 s\nSweetXml.xpath/2              0.29 - 104.44x slower +3.38 s\n```","ref":"readme.html#sample-benchmark-results"},{"type":"extras","title":"License - Overview","doc":"QuickXml is released under the [MIT License](./LICENSE).","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.1"}}